# This file was automatically generated by SWIG
package Math::LP::Solve;
*VERSION = \'3.02'; #'
require Exporter;
require DynaLoader;
@ISA = qw(Exporter DynaLoader);
package Math::LP::Solve;
bootstrap Math::LP::Solve;
var_Math__LP__Solve_init();
package Math::LP::Solve;
@EXPORT = qw( );
%EXPORT_TAGS = (
                 'ptrlib' => [
                               'ptrcast',
                               'ptrvalue',
                               'ptrset',
                               'ptrcreate',
                               'ptrfree',
                               'ptradd',
                               'ptrmap'
                             ],
                 'accessors' => [
                                  'lprec_verbose_set',
                                  'lprec_verbose_get',
                                  'lprec_print_duals_set',
                                  'lprec_print_duals_get',
                                  'lprec_print_sol_set',
                                  'lprec_print_sol_get',
                                  'lprec_debug_set',
                                  'lprec_debug_get',
                                  'lprec_print_at_invert_set',
                                  'lprec_print_at_invert_get',
                                  'lprec_trace_set',
                                  'lprec_trace_get',
                                  'lprec_anti_degen_set',
                                  'lprec_anti_degen_get',
                                  'lprec_do_presolve_set',
                                  'lprec_do_presolve_get',
                                  'lprec_rows_set',
                                  'lprec_rows_get',
                                  'lprec_rows_alloc_set',
                                  'lprec_rows_alloc_get',
                                  'lprec_columns_set',
                                  'lprec_columns_get',
                                  'lprec_columns_alloc_set',
                                  'lprec_columns_alloc_get',
                                  'lprec_sum_set',
                                  'lprec_sum_get',
                                  'lprec_sum_alloc_set',
                                  'lprec_sum_alloc_get',
                                  'lprec_names_used_set',
                                  'lprec_names_used_get',
                                  'lprec_non_zeros_set',
                                  'lprec_non_zeros_get',
                                  'lprec_mat_alloc_set',
                                  'lprec_mat_alloc_get',
                                  'lprec_mat_set',
                                  'lprec_mat_get',
                                  'lprec_col_end_set',
                                  'lprec_col_end_get',
                                  'lprec_col_no_set',
                                  'lprec_col_no_get',
                                  'lprec_row_end_valid_set',
                                  'lprec_row_end_valid_get',
                                  'lprec_row_end_set',
                                  'lprec_row_end_get',
                                  'lprec_orig_rh_set',
                                  'lprec_orig_rh_get',
                                  'lprec_rh_set',
                                  'lprec_rh_get',
                                  'lprec_rhs_set',
                                  'lprec_rhs_get',
                                  'lprec_must_be_int_set',
                                  'lprec_must_be_int_get',
                                  'lprec_orig_upbo_set',
                                  'lprec_orig_upbo_get',
                                  'lprec_orig_lowbo_set',
                                  'lprec_orig_lowbo_get',
                                  'lprec_upbo_set',
                                  'lprec_upbo_get',
                                  'lprec_lowbo_set',
                                  'lprec_lowbo_get',
                                  'lprec_basis_valid_set',
                                  'lprec_basis_valid_get',
                                  'lprec_bas_set',
                                  'lprec_bas_get',
                                  'lprec_basis_set',
                                  'lprec_basis_get',
                                  'lprec_lower_set',
                                  'lprec_lower_get',
                                  'lprec_eta_valid_set',
                                  'lprec_eta_valid_get',
                                  'lprec_eta_alloc_set',
                                  'lprec_eta_alloc_get',
                                  'lprec_eta_size_set',
                                  'lprec_eta_size_get',
                                  'lprec_num_inv_set',
                                  'lprec_num_inv_get',
                                  'lprec_max_num_inv_set',
                                  'lprec_max_num_inv_get',
                                  'lprec_eta_value_set',
                                  'lprec_eta_value_get',
                                  'lprec_eta_row_nr_set',
                                  'lprec_eta_row_nr_get',
                                  'lprec_eta_col_end_set',
                                  'lprec_eta_col_end_get',
                                  'lprec_bb_rule_set',
                                  'lprec_bb_rule_get',
                                  'lprec_break_at_int_set',
                                  'lprec_break_at_int_get',
                                  'lprec_break_value_set',
                                  'lprec_break_value_get',
                                  'lprec_obj_bound_set',
                                  'lprec_obj_bound_get',
                                  'lprec_iter_set',
                                  'lprec_iter_get',
                                  'lprec_total_iter_set',
                                  'lprec_total_iter_get',
                                  'lprec_max_level_set',
                                  'lprec_max_level_get',
                                  'lprec_total_nodes_set',
                                  'lprec_total_nodes_get',
                                  'lprec_solution_set',
                                  'lprec_solution_get',
                                  'lprec_best_solution_set',
                                  'lprec_best_solution_get',
                                  'lprec_duals_set',
                                  'lprec_duals_get',
                                  'lprec_maximise_set',
                                  'lprec_maximise_get',
                                  'lprec_floor_first_set',
                                  'lprec_floor_first_get',
                                  'lprec_ch_sign_set',
                                  'lprec_ch_sign_get',
                                  'lprec_scaling_used_set',
                                  'lprec_scaling_used_get',
                                  'lprec_columns_scaled_set',
                                  'lprec_columns_scaled_get',
                                  'lprec_scale_set',
                                  'lprec_scale_get',
                                  'lprec_nr_lagrange_set',
                                  'lprec_nr_lagrange_get',
                                  'lprec_lag_row_set',
                                  'lprec_lag_row_get',
                                  'lprec_lag_rhs_set',
                                  'lprec_lag_rhs_get',
                                  'lprec_lambda_set',
                                  'lprec_lambda_get',
                                  'lprec_lag_con_type_set',
                                  'lprec_lag_con_type_get',
                                  'lprec_lag_bound_set',
                                  'lprec_lag_bound_get',
                                  'lprec_valid_set',
                                  'lprec_valid_get',
                                  'lprec_infinite_set',
                                  'lprec_infinite_get',
                                  'lprec_epsilon_set',
                                  'lprec_epsilon_get',
                                  'lprec_epsb_set',
                                  'lprec_epsb_get',
                                  'lprec_epsd_set',
                                  'lprec_epsd_get',
                                  'lprec_epsel_set',
                                  'lprec_epsel_get',
                                  'lprec_rowname_hashtab_set',
                                  'lprec_rowname_hashtab_get',
                                  'lprec_colname_hashtab_set',
                                  'lprec_colname_hashtab_get',
                                  'lprec_lp_name_get',
                                  'lprec_lp_name_set',
                                  'lprec_row_name_get',
                                  'lprec_row_name_set',
                                  'lprec_col_name_get',
                                  'lprec_col_name_set'
                                ],
                 'functions' => [
                                  'make_lp',
                                  'read_lp_file',
                                  'delete_lp',
                                  'copy_lp',
                                  'set_mat',
                                  'set_obj_fn',
                                  'str_set_obj_fn',
                                  'add_constraint',
                                  'str_add_constraint',
                                  'del_constraint',
                                  'add_lag_con',
                                  'str_add_lag_con',
                                  'add_column',
                                  'str_add_column',
                                  'del_column',
                                  'set_upbo',
                                  'set_lowbo',
                                  'set_int',
                                  'set_rh',
                                  'set_rh_vec',
                                  'str_set_rh_vec',
                                  'set_maxim',
                                  'set_minim',
                                  'set_constr_type',
                                  'set_row_name',
                                  'set_col_name',
                                  'auto_scale',
                                  'unscale',
                                  'solve',
                                  'lag_solve',
                                  'reset_basis',
                                  'mat_elm',
                                  'get_row',
                                  'get_column',
                                  'get_reduced_costs',
                                  'is_feasible',
                                  'column_in_lp',
                                  'read_mps',
                                  'write_MPS',
                                  'write_LP',
                                  'print_lp',
                                  'print_solution',
                                  'print_duals',
                                  'print_scales',
                                  'open_file',
                                  'close_file'
                                ],
                 'ALL' => [
                            'lprec_verbose_set',
                            'lprec_verbose_get',
                            'lprec_print_duals_set',
                            'lprec_print_duals_get',
                            'lprec_print_sol_set',
                            'lprec_print_sol_get',
                            'lprec_debug_set',
                            'lprec_debug_get',
                            'lprec_print_at_invert_set',
                            'lprec_print_at_invert_get',
                            'lprec_trace_set',
                            'lprec_trace_get',
                            'lprec_anti_degen_set',
                            'lprec_anti_degen_get',
                            'lprec_do_presolve_set',
                            'lprec_do_presolve_get',
                            'lprec_rows_set',
                            'lprec_rows_get',
                            'lprec_rows_alloc_set',
                            'lprec_rows_alloc_get',
                            'lprec_columns_set',
                            'lprec_columns_get',
                            'lprec_columns_alloc_set',
                            'lprec_columns_alloc_get',
                            'lprec_sum_set',
                            'lprec_sum_get',
                            'lprec_sum_alloc_set',
                            'lprec_sum_alloc_get',
                            'lprec_names_used_set',
                            'lprec_names_used_get',
                            'lprec_non_zeros_set',
                            'lprec_non_zeros_get',
                            'lprec_mat_alloc_set',
                            'lprec_mat_alloc_get',
                            'lprec_mat_set',
                            'lprec_mat_get',
                            'lprec_col_end_set',
                            'lprec_col_end_get',
                            'lprec_col_no_set',
                            'lprec_col_no_get',
                            'lprec_row_end_valid_set',
                            'lprec_row_end_valid_get',
                            'lprec_row_end_set',
                            'lprec_row_end_get',
                            'lprec_orig_rh_set',
                            'lprec_orig_rh_get',
                            'lprec_rh_set',
                            'lprec_rh_get',
                            'lprec_rhs_set',
                            'lprec_rhs_get',
                            'lprec_must_be_int_set',
                            'lprec_must_be_int_get',
                            'lprec_orig_upbo_set',
                            'lprec_orig_upbo_get',
                            'lprec_orig_lowbo_set',
                            'lprec_orig_lowbo_get',
                            'lprec_upbo_set',
                            'lprec_upbo_get',
                            'lprec_lowbo_set',
                            'lprec_lowbo_get',
                            'lprec_basis_valid_set',
                            'lprec_basis_valid_get',
                            'lprec_bas_set',
                            'lprec_bas_get',
                            'lprec_basis_set',
                            'lprec_basis_get',
                            'lprec_lower_set',
                            'lprec_lower_get',
                            'lprec_eta_valid_set',
                            'lprec_eta_valid_get',
                            'lprec_eta_alloc_set',
                            'lprec_eta_alloc_get',
                            'lprec_eta_size_set',
                            'lprec_eta_size_get',
                            'lprec_num_inv_set',
                            'lprec_num_inv_get',
                            'lprec_max_num_inv_set',
                            'lprec_max_num_inv_get',
                            'lprec_eta_value_set',
                            'lprec_eta_value_get',
                            'lprec_eta_row_nr_set',
                            'lprec_eta_row_nr_get',
                            'lprec_eta_col_end_set',
                            'lprec_eta_col_end_get',
                            'lprec_bb_rule_set',
                            'lprec_bb_rule_get',
                            'lprec_break_at_int_set',
                            'lprec_break_at_int_get',
                            'lprec_break_value_set',
                            'lprec_break_value_get',
                            'lprec_obj_bound_set',
                            'lprec_obj_bound_get',
                            'lprec_iter_set',
                            'lprec_iter_get',
                            'lprec_total_iter_set',
                            'lprec_total_iter_get',
                            'lprec_max_level_set',
                            'lprec_max_level_get',
                            'lprec_total_nodes_set',
                            'lprec_total_nodes_get',
                            'lprec_solution_set',
                            'lprec_solution_get',
                            'lprec_best_solution_set',
                            'lprec_best_solution_get',
                            'lprec_duals_set',
                            'lprec_duals_get',
                            'lprec_maximise_set',
                            'lprec_maximise_get',
                            'lprec_floor_first_set',
                            'lprec_floor_first_get',
                            'lprec_ch_sign_set',
                            'lprec_ch_sign_get',
                            'lprec_scaling_used_set',
                            'lprec_scaling_used_get',
                            'lprec_columns_scaled_set',
                            'lprec_columns_scaled_get',
                            'lprec_scale_set',
                            'lprec_scale_get',
                            'lprec_nr_lagrange_set',
                            'lprec_nr_lagrange_get',
                            'lprec_lag_row_set',
                            'lprec_lag_row_get',
                            'lprec_lag_rhs_set',
                            'lprec_lag_rhs_get',
                            'lprec_lambda_set',
                            'lprec_lambda_get',
                            'lprec_lag_con_type_set',
                            'lprec_lag_con_type_get',
                            'lprec_lag_bound_set',
                            'lprec_lag_bound_get',
                            'lprec_valid_set',
                            'lprec_valid_get',
                            'lprec_infinite_set',
                            'lprec_infinite_get',
                            'lprec_epsilon_set',
                            'lprec_epsilon_get',
                            'lprec_epsb_set',
                            'lprec_epsb_get',
                            'lprec_epsd_set',
                            'lprec_epsd_get',
                            'lprec_epsel_set',
                            'lprec_epsel_get',
                            'lprec_rowname_hashtab_set',
                            'lprec_rowname_hashtab_get',
                            'lprec_colname_hashtab_set',
                            'lprec_colname_hashtab_get',
                            'lprec_lp_name_get',
                            'lprec_lp_name_set',
                            'lprec_row_name_get',
                            'lprec_row_name_set',
                            'lprec_col_name_get',
                            'lprec_col_name_set',
                            'make_lp',
                            'read_lp_file',
                            'delete_lp',
                            'copy_lp',
                            'set_mat',
                            'set_obj_fn',
                            'str_set_obj_fn',
                            'add_constraint',
                            'str_add_constraint',
                            'del_constraint',
                            'add_lag_con',
                            'str_add_lag_con',
                            'add_column',
                            'str_add_column',
                            'del_column',
                            'set_upbo',
                            'set_lowbo',
                            'set_int',
                            'set_rh',
                            'set_rh_vec',
                            'str_set_rh_vec',
                            'set_maxim',
                            'set_minim',
                            'set_constr_type',
                            'set_row_name',
                            'set_col_name',
                            'auto_scale',
                            'unscale',
                            'solve',
                            'lag_solve',
                            'reset_basis',
                            'mat_elm',
                            'get_row',
                            'get_column',
                            'get_reduced_costs',
                            'is_feasible',
                            'column_in_lp',
                            'read_mps',
                            'write_MPS',
                            'write_LP',
                            'print_lp',
                            'print_solution',
                            'print_duals',
                            'print_scales',
                            'open_file',
                            'close_file',
                            'ptrcast',
                            'ptrvalue',
                            'ptrset',
                            'ptrcreate',
                            'ptrfree',
                            'ptradd',
                            'ptrmap',
                            '$DEF_INFINITE',
                            '$LE',
                            '$EQ',
                            '$GE',
                            '$OF',
                            '$FALSE',
                            '$TRUE',
                            '$OPTIMAL',
                            '$MILP_FAIL',
                            '$INFEASIBLE',
                            '$UNBOUNDED',
                            '$FAILURE',
                            '$RUNNING',
                            '$FEAS_FOUND',
                            '$NO_FEAS_FOUND',
                            '$BREAK_BB'
                          ],
                 'scalars' => [
                                '$DEF_INFINITE',
                                '$LE',
                                '$EQ',
                                '$GE',
                                '$OF',
                                '$FALSE',
                                '$TRUE',
                                '$OPTIMAL',
                                '$MILP_FAIL',
                                '$INFEASIBLE',
                                '$UNBOUNDED',
                                '$FAILURE',
                                '$RUNNING',
                                '$FEAS_FOUND',
                                '$NO_FEAS_FOUND',
                                '$BREAK_BB'
                              ]
               );
@EXPORT_OK = (
               'lprec_verbose_set',
               'lprec_verbose_get',
               'lprec_print_duals_set',
               'lprec_print_duals_get',
               'lprec_print_sol_set',
               'lprec_print_sol_get',
               'lprec_debug_set',
               'lprec_debug_get',
               'lprec_print_at_invert_set',
               'lprec_print_at_invert_get',
               'lprec_trace_set',
               'lprec_trace_get',
               'lprec_anti_degen_set',
               'lprec_anti_degen_get',
               'lprec_do_presolve_set',
               'lprec_do_presolve_get',
               'lprec_rows_set',
               'lprec_rows_get',
               'lprec_rows_alloc_set',
               'lprec_rows_alloc_get',
               'lprec_columns_set',
               'lprec_columns_get',
               'lprec_columns_alloc_set',
               'lprec_columns_alloc_get',
               'lprec_sum_set',
               'lprec_sum_get',
               'lprec_sum_alloc_set',
               'lprec_sum_alloc_get',
               'lprec_names_used_set',
               'lprec_names_used_get',
               'lprec_non_zeros_set',
               'lprec_non_zeros_get',
               'lprec_mat_alloc_set',
               'lprec_mat_alloc_get',
               'lprec_mat_set',
               'lprec_mat_get',
               'lprec_col_end_set',
               'lprec_col_end_get',
               'lprec_col_no_set',
               'lprec_col_no_get',
               'lprec_row_end_valid_set',
               'lprec_row_end_valid_get',
               'lprec_row_end_set',
               'lprec_row_end_get',
               'lprec_orig_rh_set',
               'lprec_orig_rh_get',
               'lprec_rh_set',
               'lprec_rh_get',
               'lprec_rhs_set',
               'lprec_rhs_get',
               'lprec_must_be_int_set',
               'lprec_must_be_int_get',
               'lprec_orig_upbo_set',
               'lprec_orig_upbo_get',
               'lprec_orig_lowbo_set',
               'lprec_orig_lowbo_get',
               'lprec_upbo_set',
               'lprec_upbo_get',
               'lprec_lowbo_set',
               'lprec_lowbo_get',
               'lprec_basis_valid_set',
               'lprec_basis_valid_get',
               'lprec_bas_set',
               'lprec_bas_get',
               'lprec_basis_set',
               'lprec_basis_get',
               'lprec_lower_set',
               'lprec_lower_get',
               'lprec_eta_valid_set',
               'lprec_eta_valid_get',
               'lprec_eta_alloc_set',
               'lprec_eta_alloc_get',
               'lprec_eta_size_set',
               'lprec_eta_size_get',
               'lprec_num_inv_set',
               'lprec_num_inv_get',
               'lprec_max_num_inv_set',
               'lprec_max_num_inv_get',
               'lprec_eta_value_set',
               'lprec_eta_value_get',
               'lprec_eta_row_nr_set',
               'lprec_eta_row_nr_get',
               'lprec_eta_col_end_set',
               'lprec_eta_col_end_get',
               'lprec_bb_rule_set',
               'lprec_bb_rule_get',
               'lprec_break_at_int_set',
               'lprec_break_at_int_get',
               'lprec_break_value_set',
               'lprec_break_value_get',
               'lprec_obj_bound_set',
               'lprec_obj_bound_get',
               'lprec_iter_set',
               'lprec_iter_get',
               'lprec_total_iter_set',
               'lprec_total_iter_get',
               'lprec_max_level_set',
               'lprec_max_level_get',
               'lprec_total_nodes_set',
               'lprec_total_nodes_get',
               'lprec_solution_set',
               'lprec_solution_get',
               'lprec_best_solution_set',
               'lprec_best_solution_get',
               'lprec_duals_set',
               'lprec_duals_get',
               'lprec_maximise_set',
               'lprec_maximise_get',
               'lprec_floor_first_set',
               'lprec_floor_first_get',
               'lprec_ch_sign_set',
               'lprec_ch_sign_get',
               'lprec_scaling_used_set',
               'lprec_scaling_used_get',
               'lprec_columns_scaled_set',
               'lprec_columns_scaled_get',
               'lprec_scale_set',
               'lprec_scale_get',
               'lprec_nr_lagrange_set',
               'lprec_nr_lagrange_get',
               'lprec_lag_row_set',
               'lprec_lag_row_get',
               'lprec_lag_rhs_set',
               'lprec_lag_rhs_get',
               'lprec_lambda_set',
               'lprec_lambda_get',
               'lprec_lag_con_type_set',
               'lprec_lag_con_type_get',
               'lprec_lag_bound_set',
               'lprec_lag_bound_get',
               'lprec_valid_set',
               'lprec_valid_get',
               'lprec_infinite_set',
               'lprec_infinite_get',
               'lprec_epsilon_set',
               'lprec_epsilon_get',
               'lprec_epsb_set',
               'lprec_epsb_get',
               'lprec_epsd_set',
               'lprec_epsd_get',
               'lprec_epsel_set',
               'lprec_epsel_get',
               'lprec_rowname_hashtab_set',
               'lprec_rowname_hashtab_get',
               'lprec_colname_hashtab_set',
               'lprec_colname_hashtab_get',
               'lprec_lp_name_get',
               'lprec_lp_name_set',
               'lprec_row_name_get',
               'lprec_row_name_set',
               'lprec_col_name_get',
               'lprec_col_name_set',
               'make_lp',
               'read_lp_file',
               'delete_lp',
               'copy_lp',
               'set_mat',
               'set_obj_fn',
               'str_set_obj_fn',
               'add_constraint',
               'str_add_constraint',
               'del_constraint',
               'add_lag_con',
               'str_add_lag_con',
               'add_column',
               'str_add_column',
               'del_column',
               'set_upbo',
               'set_lowbo',
               'set_int',
               'set_rh',
               'set_rh_vec',
               'str_set_rh_vec',
               'set_maxim',
               'set_minim',
               'set_constr_type',
               'set_row_name',
               'set_col_name',
               'auto_scale',
               'unscale',
               'solve',
               'lag_solve',
               'reset_basis',
               'mat_elm',
               'get_row',
               'get_column',
               'get_reduced_costs',
               'is_feasible',
               'column_in_lp',
               'read_mps',
               'write_MPS',
               'write_LP',
               'print_lp',
               'print_solution',
               'print_duals',
               'print_scales',
               'open_file',
               'close_file',
               'ptrcast',
               'ptrvalue',
               'ptrset',
               'ptrcreate',
               'ptrfree',
               'ptradd',
               'ptrmap',
               '$DEF_INFINITE',
               '$LE',
               '$EQ',
               '$GE',
               '$OF',
               '$FALSE',
               '$TRUE',
               '$OPTIMAL',
               '$MILP_FAIL',
               '$INFEASIBLE',
               '$UNBOUNDED',
               '$FAILURE',
               '$RUNNING',
               '$FEAS_FOUND',
               '$NO_FEAS_FOUND',
               '$BREAK_BB'
             );
1;
